==> openjdk-21_21.0.9~8ea.orig.tar.xz: openjdk-21-21.0.9~8ea/src/hotspot/share/gc/z/zUncommitter.hpp <==
/*
 * Copyright (c) 2019, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#ifndef SHARE_GC_Z_ZUNCOMMITTER_HPP
#define SHARE_GC_Z_ZUNCOMMITTER_HPP

#include "gc/z/zLock.hpp"
#include "gc/z/zThread.hpp"

class ZPageAllocator;

class ZUncommitter : public ZThread {
private:
  ZPageAllocator* const  _page_allocator;
  mutable ZConditionLock _lock;
  bool                   _stop;

  bool wait(uint64_t timeout) const;
  bool should_continue() const;

protected:
  virtual void run_thread();
  virtual void terminate();

public:
  ZUncommitter(ZPageAllocator* page_allocator);
};

#endif // SHARE_GC_Z_ZUNCOMMITTER_HPP

==> openjdk-25_25~25ea.orig.tar.xz: openjdk-25-25~25ea/src/hotspot/share/gc/z/zUncommitter.hpp <==
/*
 * Copyright (c) 2019, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#ifndef SHARE_GC_Z_ZUNCOMMITTER_HPP
#define SHARE_GC_Z_ZUNCOMMITTER_HPP

#include "gc/z/zLock.hpp"
#include "gc/z/zThread.hpp"

class ZPartition;

class ZUncommitter : public ZThread {
private:
  const uint32_t         _id;
  ZPartition* const      _partition;
  mutable ZConditionLock _lock;
  bool                   _stop;

  bool wait(uint64_t timeout) const;
  bool should_continue() const;

protected:
  virtual void run_thread();
  virtual void terminate();

public:
  ZUncommitter(uint32_t id, ZPartition* partition);
};

#endif // SHARE_GC_Z_ZUNCOMMITTER_HPP
